/***************************************************************************
 *   Copyright (C) 2009 by Rene Landert <rene.landert@bluewin.ch>          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 **************************************************************************/

#include "KchildlockDaemon.h"
#include <KAboutData>
#include <KPluginFactory>
#include <klocalizedstring.h>
#include "kchildlock.h"



K_PLUGIN_FACTORY(KchildlockFactory,
                 registerPlugin<KchildlockDaemon>();)
K_EXPORT_PLUGIN(KchildlockFactory("kchildlockdaemon"))


// the main program 
//=================

KchildlockDaemon::KchildlockDaemon(QObject *parent, const QList<QVariant>&)
        : KDEDModule(parent),
         data(new KchDClass()),
         my_ctfile(new CT_file())
{
    KGlobal::locale()->insertCatalog("kchildlock");

    KAboutData aboutData("kchildlock", "kchildlock", ki18n("Kchildlock Daemon"),
                         KCHILDLOCK_VERSION, ki18n("A Daemon for Kchildlock for KDE4"),
                         KAboutData::License_GPL, ki18n("(c), 2009 Rene Landert"),
                         KLocalizedString(), "This daemon "
                             "restricts the usage time of the computer per day and "
                             "per week for selected users.");

    aboutData.addAuthor(ki18n("Rene Landert"), ki18n("Maintainer"),  "rene.landert@bluewin.ch", "http://www.sourceforge.net/kchildlock");

    data->applicationData = KComponentData(aboutData);

    data->notificationTimer = new QTimer(this);
    data->startupTimer = new QTimer(this);
    data->scanTimer = new QTimer(this);
    data->my_actuserstate.date = QDate::currentDate();
    data->my_actuserstate.time = QTime::currentTime();

    QString debug_file_name = debug_log_file_name_part1;
    debug_file_name.append(debug_log_file_name_part3);
    QFile debug_file ( debug_file_name );
    if ( debug_file.exists() ) {
       data->debugflag = true;
       QString debug_log_file_name = debug_log_file_name_part1;
       QDateTime currdt = QDateTime::currentDateTime ();
       debug_log_file_name.append(currdt.toString ("yyyyMMdd_hhmmss"));
       debug_log_file_name.append(debug_log_file_name_part3);
       data->debugf = fopen ( debug_log_file_name.toAscii(), "a+");
       }
    else
       data->debugflag = false;

    if (data->debugflag) {
       fprintf (data->debugf,"\nStarting kchildlock daemon...\n");
       fprintf (data->debugf,"date and time is %i.%i. %i:%i:%i\n", data->my_actuserstate.date.day(), data->my_actuserstate.date.month(), data->my_actuserstate.time.hour(), data->my_actuserstate.time.minute(), data->my_actuserstate.time.second());
       fflush(data->debugf);
       }

    connect(data->startupTimer, SIGNAL(timeout()), this, SLOT(startupTimePassed()));
    data->startupTimer->start(60 * 1000);



}

// Destroy the object
// ==================

KchildlockDaemon::~KchildlockDaemon()
{
    delete data->ckSessionInterface;
    delete data;
}




// set the default valuse for the consumed time
// ============================================
void KchildlockDaemon::set_default_ct_values ()
{

        my_ctfile->set_default_values(data->my_actuserstate.user);
	data->my_actuserstate.warn_usr_state = KCHILDLOCK_NOWARNSTATE;
	data->my_actuserstate.warn_app_state = KCHILDLOCK_NOWARNSTATE;
}


// after the initial pause begin work
// ==================================
void KchildlockDaemon::startupTimePassed()
{
   data->my_actuserstate.date = QDate::currentDate();
   data->my_actuserstate.time = QTime::currentTime();

   if (data->debugflag) {
      fprintf (data->debugf,"\nafter the initial timeout...\n");
      fprintf (data->debugf,"date and time is %i.%i. %i:%i:%i\n", data->my_actuserstate.date.day(), data->my_actuserstate.date.month(), data->my_actuserstate.time.hour(), data->my_actuserstate.time.minute(), data->my_actuserstate.time.second());
      fprintf (data->debugf,"actual user is %s\n", data->my_actuserstate.user.toAscii().constData());
      fflush(data->debugf);
      }

   data->startupTimer->stop();

//  First things first: let's set up Kchildlock to be aware of active session
    QDBusConnection conn = QDBusConnection::systemBus();
    setUpConsoleKit();

   get_active_user ();
   bool retvalue = my_ctfile->open(data->my_actuserstate.user);

   if (data->debugflag) {
      fprintf (data->debugf,"filename %s\n", my_ctfile->ct_file_name.toAscii().constData());
      fflush(data->debugf);
      }

// get values from consumed time file
    if ( retvalue )         // file could be opened
    {
            my_ctfile->set_default_values(data->my_actuserstate.user);
            my_ctfile->read();

            if (data->debugflag) {
               fprintf (data->debugf,"consumed times values from file;\n");
               fprintf (data->debugf,"woy=%i. dow=%i. usd=%i, usw=%i\n", my_ctfile->weekofyear_ct, my_ctfile->dayofweek_ct, my_ctfile->pcusage_daily_ct, my_ctfile->pcusage_weekly_ct);
               fprintf (data->debugf,"app1=%s, usd=%i, usw=%i\n", my_ctfile->appname1_ct.toAscii().constData(), my_ctfile->app1usage_daily_ct, my_ctfile->app1usage_weekly_ct);
               fprintf (data->debugf,"app2=%s, usd=%i, usw=%i\n", my_ctfile->appname2_ct.toAscii().constData(), my_ctfile->app2usage_daily_ct, my_ctfile->app2usage_weekly_ct);
               fprintf (data->debugf,"app3=%s, usd=%i, usw=%i\n", my_ctfile->appname3_ct.toAscii().constData(), my_ctfile->app3usage_daily_ct, my_ctfile->app3usage_weekly_ct);
               fflush(data->debugf);
            }
            my_ctfile->close();
      }
      else
// set default values
      {
         my_ctfile->set_default_values(data->my_actuserstate.user);
         if (data->debugflag) {
            fprintf (data->debugf,"default consumed times values without file;\n");
            fprintf (data->debugf,"woy=%i. dow=%i. usd=%i, usw=%i\n", my_ctfile->weekofyear_ct, my_ctfile->dayofweek_ct, my_ctfile->pcusage_daily_ct, my_ctfile->pcusage_weekly_ct);
            fflush(data->debugf);
          }
      }

   if ( my_ctfile->weekofyear_ct != data->my_actuserstate.date.weekNumber() )
      {
      // its a new week, reset all consumed times values to zero
      my_ctfile->set_default_values(data->my_actuserstate.user);
      if (data->debugflag) {
         fprintf (data->debugf,"default consumed times values for a new week;\n");
         fprintf (data->debugf,"woy=%i. dow=%i. usd=%i, usw=%i\n", my_ctfile->weekofyear_ct, my_ctfile->dayofweek_ct, my_ctfile->pcusage_daily_ct, my_ctfile->pcusage_weekly_ct);
         fflush(data->debugf);
         }
      }

  connect(data->scanTimer, SIGNAL(timeout()), this, SLOT(scanTimePassed()));
  data->scanTimer->start(1000 * (KchildlockSettings::scaninterval()));

}




// after each scanintervall, moitor the system
// ===========================================
void KchildlockDaemon::scanTimePassed()
{
data->my_actuserstate.date = QDate::currentDate();
data->my_actuserstate.time = QTime::currentTime();
   if (data->debugflag) {
      fprintf (data->debugf,"\nafter the repeating timeout...\n");
      fprintf (data->debugf,"date and time is %i.%i. %i:%i:%i\n", data->my_actuserstate.date.day(), data->my_actuserstate.date.month(), data->my_actuserstate.time.hour(), data->my_actuserstate.time.minute(), data->my_actuserstate.time.second());
      fprintf (data->debugf,"actual user is %s\n", data->my_actuserstate.user.toAscii().constData());
      fflush(data->debugf);
      }
if (KchildlockSettings::enable_restrictions())
   {
   get_active_user ();
   monitor_user();
   }
}



// the active session has changed, get new active User
// ===================================================
void KchildlockDaemon::activeSessionChanged()
{
//    KchildlockSettings::self()->readConfig();
// get the active user
   data->my_actuserstate.date = QDate::currentDate();
   data->my_actuserstate.time = QTime::currentTime();
   get_active_user();
}




bool KchildlockDaemon::checkIfCurrentSessionActive()
{
    if (!data->ckAvailable) {
        // No way to determine if we are on the current session, simply suppose we are
        kDebug() << "Can't contact ck";
        return true;
    }

    QDBusReply<bool> rp = data->ckSessionInterface->call("IsActive");

    return rp.value();
}


// setup the Communication to the console Kit to be informed about active session
// ==============================================================================
void KchildlockDaemon::setUpConsoleKit()
{
    // Let's cache the needed information to check if our session is actually active

    if (!QDBusConnection::systemBus().interface()->isServiceRegistered("org.freedesktop.ConsoleKit")) {
        // No way to determine if we are on the current session, simply suppose we are
        kDebug() << "Can't contact ck";
        data->ckAvailable = false;
        return;
    } else {
        data->ckAvailable = true;
    }

    // Otherwise, let's ask ConsoleKit
    QDBusInterface ckiface("org.freedesktop.ConsoleKit", "/org/freedesktop/ConsoleKit/Manager",
                           "org.freedesktop.ConsoleKit.Manager", QDBusConnection::systemBus());

    QDBusReply<QDBusObjectPath> sessionPath = ckiface.call("GetCurrentSession");

    if (!sessionPath.isValid() || sessionPath.value().path().isEmpty()) {
        kDebug() << "The session is not registered with ck";
        data->ckAvailable = false;
        return;
    }

    data->ckSessionInterface = new QDBusInterface("org.freedesktop.ConsoleKit", sessionPath.value().path(),
            "org.freedesktop.ConsoleKit.Session", QDBusConnection::systemBus());

    if (!data->ckSessionInterface->isValid()) {
        // As above
        kDebug() << "Can't contact iface";
        data->ckAvailable = false;
        return;
    }

    /* If everything's fine, let's attach ourself to the ActiveChanged signal.
     * You'll see we're attaching to activeSessionChanged without any further checks.
     * You know why? activeSessionChanged already checks if the console is active, 
     * so the check is already happening n the underhood
     */

    QDBusConnection::systemBus().connect("org.freedesktop.ConsoleKit", sessionPath.value().path(),                                     "org.freedesktop.ConsoleKit.Session", "ActiveChanged", this, SLOT(activeSessionChanged()));

// get the active user
    get_active_user();

}

#include "KchildlockDaemon.moc"
