/***************************************************************************
 *   Copyright (C) 2009 by Rene Landert <rene.landert@bluewin.ch>          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef KCHILDLOCKDAEMON_H
#define KCHILDLOCKDAEMON_H

#define KCHILDLOCK_DEBUGFLAG true
#define KCHILDLOCK_WARNTIME3 900
#define KCHILDLOCK_WARNTIME2 600
#define KCHILDLOCK_WARNTIME1 300

#define KCHILDLOCK_NOWARNSTATE 10
#define KCHILDLOCK_WARNSTATE3 3
#define KCHILDLOCK_WARNSTATE2 2
#define KCHILDLOCK_WARNSTATE1 1
#define KCHILDLOCK_WARNSTATE0 0
#define KCHILDLOCK_WARNSTATE00 -1


#define ct_file_name_part1 "/var/opt/kchildlock/.kch_time_"
#define ct_file_name_part3 ".tmp"
#define debug_log_file_name_part1 "/var/opt/kchildlock/kchildlockd_"
#define debug_log_file_name_part3 "_debuglog.tmp"

#include <kdedmodule.h>
#include <KComponentData>
#include <QStringList>
#include "ksmserver_interface.h"
#include <KNotification>
#include "ct_file.h"


class act_user_state
{
public:
   QString user;
   QString disp;
   int warn_usr_state;
   int warn_app_state;
   QDate date;
   QTime time;
   int weekNumber;
   int secondofday;

   int lim_du, lim_wu, lim_f, lim_t;
   QString appname1, appname2, appname3;
   int app1isactive, app2isactive, app3isactive;
   int lim_app1_du, lim_app1_wu, lim_app1_f, lim_app1_t;
   int lim_app2_du, lim_app2_wu, lim_app2_f, lim_app2_t;
   int lim_app3_du, lim_app3_wu, lim_app3_f, lim_app3_t;

};


class KchDClass
{
public:
    explicit KchDClass()
            : currentConfig(0)
            , ckSessionInterface(0) {}

    OrgKdeKSMServerInterfaceInterface *ksmServerIface;

    KComponentData applicationData;
    KConfigGroup *currentConfig;

    QPointer<KNotification> notification;
    QTimer *notificationTimer;
    QTimer *startupTimer;
    QTimer *scanTimer;

    // ConsoleKit stuff
    QDBusInterface *ckSessionInterface;
    bool ckAvailable;

    QFile *d_cfg_file1,  *d_cfg_file2;
    QString string_cfg;
    act_user_state my_actuserstate;
    int scanint;
    bool debugflag;
    FILE *debugf;

};







class KDE_EXPORT KchildlockDaemon : public KDEDModule
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Kchildlock")

public:
    KchildlockDaemon(QObject *parent, const QList<QVariant>&);
    virtual ~KchildlockDaemon();

public Q_SLOTS:
    void activeSessionChanged();

private Q_SLOTS:
    void startupTimePassed();
    void scanTimePassed();

Q_SIGNALS:

private:
    void set_default_ct_values ();
    void monitor_user();
    void get_active_user();
    bool get_user_limits_u1();
    bool get_app_limits_u1();
    bool get_user_limits_u2();
    bool get_app_limits_u2();
    bool get_user_limits_u3();
    bool get_app_limits_u3();
    bool get_user_limits_u4();
    bool get_app_limits_u4();
    bool get_user_limits_u5();
    bool get_app_limits_u5();
    bool get_user_limits_g1();
    bool get_user_limits_g2();
    bool get_user_limits_g3();
    void check_user_against_limits();
    void check_user_against_applimits();
    void check_app_limit_dwu(int appusage_ct, int lim_app_dwu, QString appname);
    void check_app_limit_from(int lim_app_f, QString appname);
    void check_app_limit_to(int lim_app_t, QString appname);
    void check_usage_limit_dwu(int usage_ct, int lim_dwu);
    void check_daily_usage_limits();
    void check_daily_app_limits();
    void warning_or_logout_session(int level);
    void force_logout_session();
    void warning_or_finish_application(QString appname, int level);
    void force_app_termination(QString appname);
    void setUpConsoleKit();

    bool checkIfCurrentSessionActive();

public:
    KchDClass *data;
    CT_file *my_ctfile;
};

#endif /*KCHILDLOCKDAEMON_H*/
