/***************************************************************************
 *   Copyright (C) 2009 by Rene Landert <rene.landert@bluewin.ch>          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 **************************************************************************/

#include "ct_file.h"
#include "kchildlock.h"


CT_file::CT_file()
{
};


CT_file::~CT_file()
{
};

// open file with the consumed times
// =================================
bool CT_file::open(QString user)
{
   username_ct = user;

   char outbfr[50], inbfr[50];
   const char *inptr = inbfr;
   inptr = username_ct.toAscii().constData();
   uint i;

   for (i=0; i<sizeof(inptr); i++) {
      outbfr[2*i] = 'A' + (inptr[i]) / 16;
      outbfr[2*i+1] = 'A' + (inptr[i]) % 16;
      };
   outbfr[2*i] = 0;

   ct_file_name = ct_file_name_part1;
   ct_file_name.append(QString(outbfr));
   ct_file_name.append(ct_file_name_part3);

   ct_file = new QFile( ct_file_name );
   if (ct_file->exists ( ct_file_name ) ) {
      if ( ct_file->open ( QIODevice::ReadWrite ) ) {
          return(TRUE);
      };
   }
   else {
   ct_file->open ( QIODevice::ReadWrite );
   };
   return(FALSE);

};



// set the default valuse for the consumed times
// =============================================
void CT_file::set_default_values (QString user)
{

   version_ct = KCHILDLOCK_VERSION;
   weekofyear_ct = QDate::currentDate().weekNumber();
   dayofweek_ct = QDate::currentDate().dayOfWeek();
   username_ct = user;
   pcusage_daily_ct = 0;
   pcusage_weekly_ct = 0;

   app1usage_daily_ct = 0;
   app2usage_daily_ct = 0;
   app3usage_daily_ct = 0;
   app1usage_weekly_ct = 0;
   app2usage_weekly_ct = 0;
   app3usage_weekly_ct = 0;
};


// reset the daily valuse for a new day
// ====================================
void CT_file::reset_daily_values ()
{

   weekofyear_ct = QDate::currentDate().weekNumber();
   dayofweek_ct = QDate::currentDate().dayOfWeek();
   pcusage_daily_ct = 0;
   app1usage_daily_ct = 0;
   app2usage_daily_ct = 0;
   app3usage_daily_ct = 0;

};


// read the values from the consumed time file
// ===========================================
void CT_file::read()
{

   QDataStream stream ( ct_file ); // read the data serialized from the file
   stream >> version_ct;
   stream >> weekofyear_ct;
   stream >> dayofweek_ct;
   stream >> username_ct;
   stream >> pcusage_daily_ct;
   stream >> pcusage_weekly_ct;
   stream >> appname1_ct;
   stream >> app1usage_daily_ct;
   stream >> app1usage_weekly_ct;
   stream >> appname2_ct;
   stream >> app2usage_daily_ct;
   stream >> app2usage_weekly_ct;
   stream >> appname3_ct;
   stream >> app3usage_daily_ct;
   stream >> app3usage_weekly_ct;
};


// write the values to consumed time file
// ======================================
void CT_file::write()
{

   QDataStream stream ( ct_file ); // read the data serialized from the file
   stream << version_ct;
   stream << weekofyear_ct;
   stream << dayofweek_ct;
   stream << username_ct;
   stream << pcusage_daily_ct;
   stream << pcusage_weekly_ct;
   stream << appname1_ct;
   stream << app1usage_daily_ct;
   stream << app1usage_weekly_ct;
   stream << appname2_ct;
   stream << app2usage_daily_ct;
   stream << app2usage_weekly_ct;
   stream << appname3_ct;
   stream << app3usage_daily_ct;
   stream << app3usage_weekly_ct;
};




// flush and close the working set file
// ====================================
void CT_file::close()
{
    ct_file->flush();
    ct_file->close();
};

