/***************************************************************************
 *   Copyright (C) 2009 by Rene Landert <rene.landert@bluewin.ch>          *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "KchildlockDaemon.h"

#include "kchildlock.h"
#include <kaboutdata.h>



// check the application against settings for daily or weekly max usage
// ====================================================================
void KchildlockDaemon::check_app_limit_dwu(int appusage_ct, int lim_app_dwu, QString appname)
     
{     
	if ((appusage_ct >= lim_app_dwu) && (data->my_actuserstate.warn_app_state <= KCHILDLOCK_WARNSTATE0))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE00;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE00);
	}
	else if ((appusage_ct >= lim_app_dwu) && (data->my_actuserstate.warn_app_state > KCHILDLOCK_WARNSTATE0))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE0;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE0);
	}
	else if ((appusage_ct >= (lim_app_dwu - KCHILDLOCK_WARNTIME1)) && (data->my_actuserstate.warn_app_state > KCHILDLOCK_WARNSTATE1))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE1;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE1);
	}
	else  if ((appusage_ct >= (lim_app_dwu - KCHILDLOCK_WARNTIME2)) && (data->my_actuserstate.warn_app_state > KCHILDLOCK_WARNSTATE2))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE2;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE2);
	}
	else  if ((appusage_ct >= (lim_app_dwu - KCHILDLOCK_WARNTIME3)) && (data->my_actuserstate.warn_app_state > KCHILDLOCK_WARNSTATE3))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE3;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE3);
	}
	else
	{
		// daily or weekly app usage limit not yet reaches
	}
}


// check the  application against limit "from hour:minute" (is it to early?)
// =========================================================================
void KchildlockDaemon::check_app_limit_from(int lim_app_f, QString appname)
{		
	if ((data->my_actuserstate.secondofday < lim_app_f) && (data->my_actuserstate.warn_app_state <= KCHILDLOCK_WARNSTATE0))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE00;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE00);
	}
	if ((data->my_actuserstate.secondofday < lim_app_f) && (data->my_actuserstate.warn_app_state > KCHILDLOCK_WARNSTATE0))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE0;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE0);
	}
}



// check the  application against limit "to hour:minute" (is it to late?)
// ======================================================================		
void KchildlockDaemon::check_app_limit_to(int lim_app_t, QString appname)
{
                if ((data->my_actuserstate.secondofday >= lim_app_t) && (data->my_actuserstate.warn_app_state <= KCHILDLOCK_WARNSTATE0))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE00;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE00);
	}
	else if ((data->my_actuserstate.secondofday >= lim_app_t) && (data->my_actuserstate.warn_app_state > KCHILDLOCK_WARNSTATE0))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE0;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE0);
	}
	else if ((data->my_actuserstate.secondofday >= (lim_app_t - KCHILDLOCK_WARNTIME1)) && (data->my_actuserstate.warn_app_state > KCHILDLOCK_WARNSTATE1))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE1;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE1);
	}
	else  if ((data->my_actuserstate.secondofday >= (lim_app_t - KCHILDLOCK_WARNTIME2)) && (data->my_actuserstate.warn_app_state > KCHILDLOCK_WARNSTATE2))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE2;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE2);
	}
	else  if ((data->my_actuserstate.secondofday >= (lim_app_t - KCHILDLOCK_WARNTIME3)) && (data->my_actuserstate.warn_app_state > KCHILDLOCK_WARNSTATE3))
	{
		data->my_actuserstate.warn_app_state = KCHILDLOCK_WARNSTATE3;
		warning_or_finish_application(appname,KCHILDLOCK_WARNSTATE3);
	}
	else
	{
		// late time limit not yet reached
	}
}



// check the applications against settings for daily and weekly  limitations
// =========================================================================
void KchildlockDaemon::check_daily_app_limits()

{
   if (data->debugflag) {
	fprintf (data->debugf,"function=check_daily_app_limits user=%s disp=%s at %i.%i. %i:%i:%i\n", data->my_actuserstate.user.toAscii().constData(), data->my_actuserstate.disp.toAscii().constData(), data->my_actuserstate.date.day(), data->my_actuserstate.date.month(), data->my_actuserstate.time.hour(), data->my_actuserstate.time.minute(), data->my_actuserstate.time.second());
	fprintf (data->debugf,"secondofday=%i, lim_du=%i, lim_wu=%i, lim_f=%i, lim_t=%i \n", data->my_actuserstate.secondofday, data->my_actuserstate.lim_app1_du, data->my_actuserstate.lim_app1_wu, data->my_actuserstate.lim_app1_f, data->my_actuserstate.lim_app1_t );
	fprintf (data->debugf,"secondofday=%i, lim_du=%i, lim_wu=%i, lim_f=%i, lim_t=%i \n", data->my_actuserstate.secondofday, data->my_actuserstate.lim_app2_du, data->my_actuserstate.lim_app2_wu, data->my_actuserstate.lim_app1_f, data->my_actuserstate.lim_app2_t );
	fprintf (data->debugf,"secondofday=%i, lim_du=%i, lim_wu=%i, lim_f=%i, lim_t=%i \n", data->my_actuserstate.secondofday, data->my_actuserstate.lim_app3_du, data->my_actuserstate.lim_app3_wu, data->my_actuserstate.lim_app3_f, data->my_actuserstate.lim_app3_t );
	fprintf (data->debugf,"app1=%s, usage_daily=%i, usage_weekly=%i \n", data->my_actuserstate.appname1.toAscii().constData(), my_ctfile->app1usage_daily_ct, my_ctfile->app1usage_weekly_ct);
	fprintf (data->debugf,"app2=%s, usage_daily=%i, usage_weekly=%i \n", data->my_actuserstate.appname2.toAscii().constData(), my_ctfile->app2usage_daily_ct, my_ctfile->app2usage_weekly_ct);
	fprintf (data->debugf,"app3=%s, usage_daily=%i, usage_weekly=%i \n", data->my_actuserstate.appname3.toAscii().constData(), my_ctfile->app3usage_daily_ct, my_ctfile->app3usage_weekly_ct);
        fflush(data->debugf);
   }

   if (!(data->my_actuserstate.appname1.isEmpty())  && ((data->my_actuserstate.app1isactive > 0))) {
	// check the limit 'app1 daily max usage'
	check_app_limit_dwu(my_ctfile->app1usage_daily_ct, data->my_actuserstate.lim_app1_du, data->my_actuserstate.appname1);
	// check the limit 'app1 weekly max usage'
	check_app_limit_dwu(my_ctfile->app1usage_weekly_ct, data->my_actuserstate.lim_app1_wu, data->my_actuserstate.appname1);
                // check the  limit "app1 from hour:minute" (is it to early?)
	check_app_limit_from(data->my_actuserstate.lim_app1_f, data->my_actuserstate.appname1);
                // check the  limit "ap1 to hour:minute" (is it to late?)
	check_app_limit_to(data->my_actuserstate.lim_app1_f, data->my_actuserstate.appname1);
   }

   if (!(data->my_actuserstate.appname2.isEmpty())   && ((data->my_actuserstate.app2isactive > 0))) {
	// check the limit 'app2 daily max usage'
	check_app_limit_dwu(my_ctfile->app2usage_daily_ct, data->my_actuserstate.lim_app2_du, data->my_actuserstate.appname2);
                // check the limit 'app2 weekly max usage'
	check_app_limit_dwu(my_ctfile->app2usage_weekly_ct, data->my_actuserstate.lim_app2_wu, data->my_actuserstate.appname2);
                // check the  limit "app2 from hour:minute" (is it to early?)
	check_app_limit_from(data->my_actuserstate.lim_app2_f, data->my_actuserstate.appname2);
                // check the  limit "ap2 to hour:minute" (is it to late?)
	check_app_limit_from(data->my_actuserstate.lim_app2_f, data->my_actuserstate.appname2);
   }

   if (!(data->my_actuserstate.appname3.isEmpty())   && ((data->my_actuserstate.app3isactive > 0))) {
	// check the limit 'app3 daily max usage'
	check_app_limit_dwu(my_ctfile->app3usage_daily_ct, data->my_actuserstate.lim_app3_du, data->my_actuserstate.appname3);
                // check the limit 'app3 weekly max usage'
	check_app_limit_dwu(my_ctfile->app3usage_weekly_ct, data->my_actuserstate.lim_app3_wu, data->my_actuserstate.appname3);
                // check the  limit "app3 from hour:minute" (is it to early?)
	check_app_limit_from(data->my_actuserstate.lim_app3_f, data->my_actuserstate.appname3);
                // check the  limit "ap3 to hour:minute" (is it to late?)
	check_app_limit_from(data->my_actuserstate.lim_app3_f, data->my_actuserstate.appname3);
   }
}







// get the limitations for usr1 and his applications if its the active user
// ========================================================================
bool KchildlockDaemon::get_app_limits_u1()
{
   if (data->debugflag) {
	fprintf (data->debugf,"function=get_app_limits appName1=%s\n", KchildlockSettings::appName1_u1().toAscii().constData());
        fflush(data->debugf);
   }

   if ((data->my_actuserstate.user != KchildlockSettings::usernamestring_u1()) || !(KchildlockSettings::enabled_u1()))
	return(FALSE);


   if (strcmp ("", (KchildlockSettings::appName1_u1()).toAscii().constData()) && strcmp ("", (KchildlockSettings::appName2_u1()).toAscii().constData()) && strcmp ("", (KchildlockSettings::appName3_u1()).toAscii().constData()))
	return(FALSE);


   data->my_actuserstate.appname1 = KchildlockSettings::appName1_u1();
   my_ctfile->appname1_ct = KchildlockSettings::appName1_u1();
   data->my_actuserstate.lim_app1_du = KchildlockSettings::app1maxDhr_u1() * 3600 + KchildlockSettings::app1maxDmin_u1() * 60;
   data->my_actuserstate.lim_app1_wu = KchildlockSettings::app1maxWhr_u1() * 3600 + KchildlockSettings::app1maxWmin_u1() * 60;
   data->my_actuserstate.lim_app1_f = KchildlockSettings::app1fromhr_u1() * 3600 + KchildlockSettings::app1frommin_u1() * 60;
   data->my_actuserstate.lim_app1_t = KchildlockSettings::app1tohr_u1() * 3600 + KchildlockSettings::app1tomin_u1() * 60;

   data->my_actuserstate.appname2 = KchildlockSettings::appName2_u1();
   my_ctfile->appname2_ct = KchildlockSettings::appName2_u1();
   data->my_actuserstate.lim_app2_du = KchildlockSettings::app2maxDhr_u1() * 3600 + KchildlockSettings::app2maxDmin_u1() * 60;
   data->my_actuserstate.lim_app2_wu = KchildlockSettings::app2maxWhr_u1() * 3600 + KchildlockSettings::app2maxWmin_u1() * 60;
   data->my_actuserstate.lim_app2_f = KchildlockSettings::app2fromhr_u1() * 3600 + KchildlockSettings::app2frommin_u1() * 60;
   data->my_actuserstate.lim_app2_t = KchildlockSettings::app2tohr_u1() * 3600 + KchildlockSettings::app2tomin_u1() * 60;

   data->my_actuserstate.appname3 = KchildlockSettings::appName3_u1();
   my_ctfile->appname3_ct = KchildlockSettings::appName3_u1();
   data->my_actuserstate.lim_app3_du = KchildlockSettings::app3maxDhr_u1() * 3600 + KchildlockSettings::app3maxDmin_u1() * 60;
   data->my_actuserstate.lim_app3_wu = KchildlockSettings::app3maxWhr_u1() * 3600 + KchildlockSettings::app3maxWmin_u1() * 60;
   data->my_actuserstate.lim_app3_f = KchildlockSettings::app3fromhr_u1() * 3600 + KchildlockSettings::app3frommin_u1() * 60;
   data->my_actuserstate.lim_app3_t = KchildlockSettings::app3tohr_u1() * 3600 + KchildlockSettings::app3tomin_u1() * 60;

   return(TRUE);
}







// get the limitations for usr2 and his applications if its the active user
// ========================================================================
bool KchildlockDaemon::get_app_limits_u2()
{
   if (data->debugflag) {
	fprintf (data->debugf,"function=get_app_limits appName1=%s\n", KchildlockSettings::appName1_u2().toAscii().constData());
        fflush(data->debugf);
   }

   if ((data->my_actuserstate.user != KchildlockSettings::usernamestring_u2()) || !(KchildlockSettings::enabled_u2()))
	return(FALSE);


   if (strcmp ("", (KchildlockSettings::appName1_u2()).toAscii().constData()) && strcmp ("", (KchildlockSettings::appName2_u2()).toAscii().constData()) && strcmp ("", (KchildlockSettings::appName3_u2()).toAscii().constData()))
	return(FALSE);


   data->my_actuserstate.appname1 = KchildlockSettings::appName1_u2();
   my_ctfile->appname1_ct = KchildlockSettings::appName1_u2();
   data->my_actuserstate.lim_app1_du = KchildlockSettings::app1maxDhr_u2() * 3600 + KchildlockSettings::app1maxDmin_u2() * 60;
   data->my_actuserstate.lim_app1_wu = KchildlockSettings::app1maxWhr_u2() * 3600 + KchildlockSettings::app1maxWmin_u2() * 60;
   data->my_actuserstate.lim_app1_f = KchildlockSettings::app1fromhr_u2() * 3600 + KchildlockSettings::app1frommin_u2() * 60;
   data->my_actuserstate.lim_app1_t = KchildlockSettings::app1tohr_u2() * 3600 + KchildlockSettings::app1tomin_u2() * 60;

   data->my_actuserstate.appname2 = KchildlockSettings::appName2_u2();
   my_ctfile->appname2_ct = KchildlockSettings::appName2_u2();
   data->my_actuserstate.lim_app2_du = KchildlockSettings::app2maxDhr_u2() * 3600 + KchildlockSettings::app2maxDmin_u2() * 60;
   data->my_actuserstate.lim_app2_wu = KchildlockSettings::app2maxWhr_u2() * 3600 + KchildlockSettings::app2maxWmin_u2() * 60;
   data->my_actuserstate.lim_app2_f = KchildlockSettings::app2fromhr_u2() * 3600 + KchildlockSettings::app2frommin_u2() * 60;
   data->my_actuserstate.lim_app2_t = KchildlockSettings::app2tohr_u2() * 3600 + KchildlockSettings::app2tomin_u2() * 60;

   data->my_actuserstate.appname3 = KchildlockSettings::appName3_u2();
   my_ctfile->appname3_ct = KchildlockSettings::appName3_u2();
   data->my_actuserstate.lim_app3_du = KchildlockSettings::app3maxDhr_u2() * 3600 + KchildlockSettings::app3maxDmin_u2() * 60;
   data->my_actuserstate.lim_app3_wu = KchildlockSettings::app3maxWhr_u2() * 3600 + KchildlockSettings::app3maxWmin_u2() * 60;
   data->my_actuserstate.lim_app3_f = KchildlockSettings::app3fromhr_u2() * 3600 + KchildlockSettings::app3frommin_u2() * 60;
   data->my_actuserstate.lim_app3_t = KchildlockSettings::app3tohr_u2() * 3600 + KchildlockSettings::app3tomin_u2() * 60;

   return(TRUE);
}







// get the limitations for usr3 and his applications if its the active user
// ========================================================================
bool KchildlockDaemon::get_app_limits_u3()
{
   if (data->debugflag) {
	fprintf (data->debugf,"function=get_app_limits appName1=%s\n", KchildlockSettings::appName1_u3().toAscii().constData());
        fflush(data->debugf);
   }

   if ((data->my_actuserstate.user != KchildlockSettings::usernamestring_u3()) || !(KchildlockSettings::enabled_u3()))
	return(FALSE);


   if (strcmp ("", (KchildlockSettings::appName1_u3()).toAscii().constData()) && strcmp ("", (KchildlockSettings::appName2_u3()).toAscii().constData()) && strcmp ("", (KchildlockSettings::appName3_u3()).toAscii().constData()))
	return(FALSE);


   data->my_actuserstate.appname1 = KchildlockSettings::appName1_u3();
   my_ctfile->appname1_ct = KchildlockSettings::appName1_u3();
   data->my_actuserstate.lim_app1_du = KchildlockSettings::app1maxDhr_u3() * 3600 + KchildlockSettings::app1maxDmin_u3() * 60;
   data->my_actuserstate.lim_app1_wu = KchildlockSettings::app1maxWhr_u3() * 3600 + KchildlockSettings::app1maxWmin_u3() * 60;
   data->my_actuserstate.lim_app1_f = KchildlockSettings::app1fromhr_u3() * 3600 + KchildlockSettings::app1frommin_u3() * 60;
   data->my_actuserstate.lim_app1_t = KchildlockSettings::app1tohr_u3() * 3600 + KchildlockSettings::app1tomin_u3() * 60;

   data->my_actuserstate.appname2 = KchildlockSettings::appName2_u3();
   my_ctfile->appname2_ct = KchildlockSettings::appName2_u3();
   data->my_actuserstate.lim_app2_du = KchildlockSettings::app2maxDhr_u3() * 3600 + KchildlockSettings::app2maxDmin_u3() * 60;
   data->my_actuserstate.lim_app2_wu = KchildlockSettings::app2maxWhr_u3() * 3600 + KchildlockSettings::app2maxWmin_u3() * 60;
   data->my_actuserstate.lim_app2_f = KchildlockSettings::app2fromhr_u3() * 3600 + KchildlockSettings::app2frommin_u3() * 60;
   data->my_actuserstate.lim_app2_t = KchildlockSettings::app2tohr_u3() * 3600 + KchildlockSettings::app2tomin_u3() * 60;

   data->my_actuserstate.appname3 = KchildlockSettings::appName3_u3();
   my_ctfile->appname3_ct = KchildlockSettings::appName3_u3();
   data->my_actuserstate.lim_app3_du = KchildlockSettings::app3maxDhr_u3() * 3600 + KchildlockSettings::app3maxDmin_u3() * 60;
   data->my_actuserstate.lim_app3_wu = KchildlockSettings::app3maxWhr_u3() * 3600 + KchildlockSettings::app3maxWmin_u3() * 60;
   data->my_actuserstate.lim_app3_f = KchildlockSettings::app3fromhr_u3() * 3600 + KchildlockSettings::app3frommin_u3() * 60;
   data->my_actuserstate.lim_app3_t = KchildlockSettings::app3tohr_u3() * 3600 + KchildlockSettings::app3tomin_u3() * 60;

   return(TRUE);
}







// get the limitations for usr4 and his applications if its the active user
// ========================================================================
bool KchildlockDaemon::get_app_limits_u4()
{
   if (data->debugflag) {
	fprintf (data->debugf,"function=get_app_limits appName1=%s\n", KchildlockSettings::appName1_u4().toAscii().constData());
        fflush(data->debugf);
   }

   if ((data->my_actuserstate.user != KchildlockSettings::usernamestring_u4()) || !(KchildlockSettings::enabled_u4()))
	return(FALSE);


   if (strcmp ("", (KchildlockSettings::appName1_u4()).toAscii().constData()) && strcmp ("", (KchildlockSettings::appName2_u4()).toAscii().constData()) && strcmp ("", (KchildlockSettings::appName3_u4()).toAscii().constData()))
	return(FALSE);


   data->my_actuserstate.appname1 = KchildlockSettings::appName1_u4();
   my_ctfile->appname1_ct = KchildlockSettings::appName1_u4();
   data->my_actuserstate.lim_app1_du = KchildlockSettings::app1maxDhr_u4() * 3600 + KchildlockSettings::app1maxDmin_u4() * 60;
   data->my_actuserstate.lim_app1_wu = KchildlockSettings::app1maxWhr_u4() * 3600 + KchildlockSettings::app1maxWmin_u4() * 60;
   data->my_actuserstate.lim_app1_f = KchildlockSettings::app1fromhr_u4() * 3600 + KchildlockSettings::app1frommin_u4() * 60;
   data->my_actuserstate.lim_app1_t = KchildlockSettings::app1tohr_u4() * 3600 + KchildlockSettings::app1tomin_u4() * 60;

   data->my_actuserstate.appname2 = KchildlockSettings::appName2_u4();
   my_ctfile->appname2_ct = KchildlockSettings::appName2_u4();
   data->my_actuserstate.lim_app2_du = KchildlockSettings::app2maxDhr_u4() * 3600 + KchildlockSettings::app2maxDmin_u4() * 60;
   data->my_actuserstate.lim_app2_wu = KchildlockSettings::app2maxWhr_u4() * 3600 + KchildlockSettings::app2maxWmin_u4() * 60;
   data->my_actuserstate.lim_app2_f = KchildlockSettings::app2fromhr_u4() * 3600 + KchildlockSettings::app2frommin_u4() * 60;
   data->my_actuserstate.lim_app2_t = KchildlockSettings::app2tohr_u4() * 3600 + KchildlockSettings::app2tomin_u4() * 60;

   data->my_actuserstate.appname3 = KchildlockSettings::appName3_u4();
   my_ctfile->appname3_ct = KchildlockSettings::appName3_u4();
   data->my_actuserstate.lim_app3_du = KchildlockSettings::app3maxDhr_u4() * 3600 + KchildlockSettings::app3maxDmin_u4() * 60;
   data->my_actuserstate.lim_app3_wu = KchildlockSettings::app3maxWhr_u4() * 3600 + KchildlockSettings::app3maxWmin_u4() * 60;
   data->my_actuserstate.lim_app3_f = KchildlockSettings::app3fromhr_u4() * 3600 + KchildlockSettings::app3frommin_u4() * 60;
   data->my_actuserstate.lim_app3_t = KchildlockSettings::app3tohr_u4() * 3600 + KchildlockSettings::app3tomin_u4() * 60;

   return(TRUE);
}







// get the limitations for usr5 and his applications if its the active user
// ========================================================================
bool KchildlockDaemon::get_app_limits_u5()
{
   if (data->debugflag) {
	fprintf (data->debugf,"function=get_app_limits appName1=%s\n", KchildlockSettings::appName1_u5().toAscii().constData());
        fflush(data->debugf);
   }

   if ((data->my_actuserstate.user != KchildlockSettings::usernamestring_u5()) || !(KchildlockSettings::enabled_u5()))
	return(FALSE);


   if (strcmp ("", (KchildlockSettings::appName1_u5()).toAscii().constData()) && strcmp ("", (KchildlockSettings::appName2_u5()).toAscii().constData()) && strcmp ("", (KchildlockSettings::appName3_u5()).toAscii().constData()))
	return(FALSE);


   data->my_actuserstate.appname1 = KchildlockSettings::appName1_u5();
   my_ctfile->appname1_ct = KchildlockSettings::appName1_u5();
   data->my_actuserstate.lim_app1_du = KchildlockSettings::app1maxDhr_u5() * 3600 + KchildlockSettings::app1maxDmin_u5() * 60;
   data->my_actuserstate.lim_app1_wu = KchildlockSettings::app1maxWhr_u5() * 3600 + KchildlockSettings::app1maxWmin_u5() * 60;
   data->my_actuserstate.lim_app1_f = KchildlockSettings::app1fromhr_u5() * 3600 + KchildlockSettings::app1frommin_u5() * 60;
   data->my_actuserstate.lim_app1_t = KchildlockSettings::app1tohr_u5() * 3600 + KchildlockSettings::app1tomin_u5() * 60;

   data->my_actuserstate.appname2 = KchildlockSettings::appName2_u5();
   my_ctfile->appname2_ct = KchildlockSettings::appName2_u5();
   data->my_actuserstate.lim_app2_du = KchildlockSettings::app2maxDhr_u5() * 3600 + KchildlockSettings::app2maxDmin_u5() * 60;
   data->my_actuserstate.lim_app2_wu = KchildlockSettings::app2maxWhr_u5() * 3600 + KchildlockSettings::app2maxWmin_u5() * 60;
   data->my_actuserstate.lim_app2_f = KchildlockSettings::app2fromhr_u5() * 3600 + KchildlockSettings::app2frommin_u5() * 60;
   data->my_actuserstate.lim_app2_t = KchildlockSettings::app2tohr_u5() * 3600 + KchildlockSettings::app2tomin_u5() * 60;

   data->my_actuserstate.appname3 = KchildlockSettings::appName3_u5();
   my_ctfile->appname3_ct = KchildlockSettings::appName3_u5();
   data->my_actuserstate.lim_app3_du = KchildlockSettings::app3maxDhr_u5() * 3600 + KchildlockSettings::app3maxDmin_u5() * 60;
   data->my_actuserstate.lim_app3_wu = KchildlockSettings::app3maxWhr_u5() * 3600 + KchildlockSettings::app3maxWmin_u5() * 60;
   data->my_actuserstate.lim_app3_f = KchildlockSettings::app3fromhr_u5() * 3600 + KchildlockSettings::app3frommin_u5() * 60;
   data->my_actuserstate.lim_app3_t = KchildlockSettings::app3tohr_u5() * 3600 + KchildlockSettings::app3tomin_u5() * 60;

   return(TRUE);
}




