/***************************************************************************
 *   Copyright (C) 2009 by Rene Landert <rene.landert@bluewin.ch>          *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "KchildlockDaemon.h"
#include "kchildlock.h"

#include <kuser.h>


// check user against limit 'daily or weekly max usage'
// ====================================================
void KchildlockDaemon::check_usage_limit_dwu(int usage_ct, int lim_dwu)
{
                if ((usage_ct >= lim_dwu) && (data->my_actuserstate.warn_usr_state <= KCHILDLOCK_WARNSTATE0))
	{
		data->my_actuserstate.warn_usr_state = KCHILDLOCK_WARNSTATE00;
		warning_or_logout_session(KCHILDLOCK_WARNSTATE00);
	}
	else if ((usage_ct >= lim_dwu) && (data->my_actuserstate.warn_usr_state > KCHILDLOCK_WARNSTATE0))
	{
		data->my_actuserstate.warn_usr_state = KCHILDLOCK_WARNSTATE0;
		warning_or_logout_session(KCHILDLOCK_WARNSTATE0);
	}
	else if ((usage_ct >= (lim_dwu - KCHILDLOCK_WARNTIME1)) && (data->my_actuserstate.warn_usr_state > KCHILDLOCK_WARNSTATE1))
	{
		data->my_actuserstate.warn_usr_state = KCHILDLOCK_WARNSTATE1;
		warning_or_logout_session(KCHILDLOCK_WARNSTATE1);
	}
	else  if ((usage_ct >= (lim_dwu - KCHILDLOCK_WARNTIME2)) && (data->my_actuserstate.warn_usr_state > KCHILDLOCK_WARNSTATE2))
	{
		data->my_actuserstate.warn_usr_state = KCHILDLOCK_WARNSTATE2;
		warning_or_logout_session(KCHILDLOCK_WARNSTATE2);
	}
	else  if ((usage_ct >= (lim_dwu - KCHILDLOCK_WARNTIME3)) && (data->my_actuserstate.warn_usr_state > KCHILDLOCK_WARNSTATE3))
	{
		data->my_actuserstate.warn_usr_state = KCHILDLOCK_WARNSTATE3;
		warning_or_logout_session(KCHILDLOCK_WARNSTATE3);
	}
	else
	{
		// daily usage limit not yet reaches
	}
}



// check user against settings for daily and weekly  limitations
// =============================================================
void KchildlockDaemon::check_daily_usage_limits()
{
	if (data->debugflag) {
		fprintf (data->debugf,"function=check_daily_usage_limits user=%s disp=%s at %i.%i. %i:%i:%i\n", data->my_actuserstate.user.toAscii().constData(), data->my_actuserstate.disp.toAscii().constData(), data->my_actuserstate.date.day(), data->my_actuserstate.date.month(), data->my_actuserstate.time.hour(), data->my_actuserstate.time.minute(), data->my_actuserstate.time.second());
		fprintf (data->debugf,"secondofday=%i, lim_du=%i, lim_wu=%i, lim_f=%i, lim_t=%i \n", data->my_actuserstate.secondofday, data->my_actuserstate.lim_du, data->my_actuserstate.lim_wu, data->my_actuserstate.lim_f, data->my_actuserstate.lim_t );
		fprintf (data->debugf,"usage_daily=%i, usage_weekly=%i \n", my_ctfile->pcusage_daily_ct, my_ctfile->pcusage_weekly_ct);
                fflush(data->debugf);
                }

                // check the limit 'daily max usage'
	check_usage_limit_dwu(my_ctfile->pcusage_daily_ct, data->my_actuserstate.lim_du);
                // check the limit 'weekly max usage'
	check_usage_limit_dwu(my_ctfile->pcusage_weekly_ct, data->my_actuserstate.lim_wu);
	
		
                // check the  limit "from hour:minute" (is it to early?)
	if ((data->my_actuserstate.secondofday < data->my_actuserstate.lim_f) && (data->my_actuserstate.warn_usr_state <= KCHILDLOCK_WARNSTATE0))
	{
		data->my_actuserstate.warn_usr_state = KCHILDLOCK_WARNSTATE00;
		warning_or_logout_session(KCHILDLOCK_WARNSTATE00);
	}
	if ((data->my_actuserstate.secondofday < data->my_actuserstate.lim_f) && (data->my_actuserstate.warn_usr_state > KCHILDLOCK_WARNSTATE0))
	{
		data->my_actuserstate.warn_usr_state = KCHILDLOCK_WARNSTATE0;
		warning_or_logout_session(KCHILDLOCK_WARNSTATE0);
	}
	
                // check the  limit "to hour:minute" (is it to late?)
	check_usage_limit_dwu(data->my_actuserstate.secondofday, data->my_actuserstate.lim_t);
}






// get the limitations for usr1 if its the active user
// ==================================================
bool KchildlockDaemon::get_user_limits_u1()
{

   if ((data->my_actuserstate.user != KchildlockSettings::usernamestring_u1()) || !(KchildlockSettings::enabled_u1()))
	return(FALSE);

   data->my_actuserstate.date = QDate::currentDate();
   data->my_actuserstate.lim_wu = KchildlockSettings::wEEKmaxhr_u1() * 3600 + KchildlockSettings::wEEKmaxmin_u1() * 60;

   if (KchildlockSettings::sameRestrict_u1()) {
		data->my_actuserstate.lim_du = KchildlockSettings::dAYmaxhr_u1() * 3600 + KchildlockSettings::dAYmaxmin_u1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::dAYfromhr_u1() * 3600 + KchildlockSettings::dAYfrommin_u1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::dAYtohr_u1() * 3600 + KchildlockSettings::dAYtomin_u1() * 60;
   } else {

	if (data->my_actuserstate.date.dayOfWeek() == 1 && KchildlockSettings::mONenabled_u1() )
	{
		data->my_actuserstate.lim_du = KchildlockSettings::mONmaxhr_u1() * 3600 + KchildlockSettings::mONmaxmin_u1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::mONfromhr_u1() * 3600 + KchildlockSettings::mONfrommin_u1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::mONtohr_u1() * 3600 + KchildlockSettings::mONtomin_u1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 2 && KchildlockSettings::tUEenabled_u1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tUEmaxhr_u1() * 3600 + KchildlockSettings::tUEmaxmin_u1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tUEfromhr_u1() * 3600 + KchildlockSettings::tUEfrommin_u1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tUEtohr_u1() * 3600 + KchildlockSettings::tUEtomin_u1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 3 && KchildlockSettings::wEDenabled_u1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::wEDmaxhr_u1() * 3600 + KchildlockSettings::wEDmaxmin_u1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::wEDfromhr_u1() * 3600 + KchildlockSettings::wEDfrommin_u1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::wEDtohr_u1() * 3600 + KchildlockSettings::wEDtomin_u1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 4 && KchildlockSettings::tHUenabled_u1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tHUmaxhr_u1() * 3600 + KchildlockSettings::tHUmaxmin_u1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tHUfromhr_u1() * 3600 + KchildlockSettings::tHUfrommin_u1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tHUtohr_u1() * 3600 + KchildlockSettings::tHUtomin_u1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 5 && KchildlockSettings::fRIenabled_u1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::fRImaxhr_u1() * 3600 + KchildlockSettings::fRImaxmin_u1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::fRIfromhr_u1() * 3600 + KchildlockSettings::fRIfrommin_u1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::fRItohr_u1() * 3600 + KchildlockSettings::fRItomin_u1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 6 && KchildlockSettings::sATenabled_u1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sATmaxhr_u1() * 3600 + KchildlockSettings::sATmaxmin_u1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sATfromhr_u1() * 3600 + KchildlockSettings::sATfrommin_u1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sATtohr_u1() * 3600 + KchildlockSettings::sATtomin_u1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 7 && KchildlockSettings::sUNenabled_u1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sUNmaxhr_u1() * 3600 + KchildlockSettings::sUNmaxmin_u1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sUNfromhr_u1() * 3600 + KchildlockSettings::sUNfrommin_u1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sUNtohr_u1() * 3600 + KchildlockSettings::sUNtomin_u1() * 60;
	}
	else
	{
		data->my_actuserstate.lim_du = 24 * 3600 + KCHILDLOCK_WARNTIME3;
		data->my_actuserstate.lim_f = 0;
		data->my_actuserstate.lim_t = 24 * 3600 + KCHILDLOCK_WARNTIME3;
	}
	return(TRUE);
   }		
   return(TRUE);
}




// get the limitations for usr2 if its the active user
// ==================================================
bool KchildlockDaemon::get_user_limits_u2()
{

   if ((data->my_actuserstate.user != KchildlockSettings::usernamestring_u2()) || !(KchildlockSettings::enabled_u2()))
		return(FALSE);

   data->my_actuserstate.date = QDate::currentDate();
   data->my_actuserstate.lim_wu = KchildlockSettings::wEEKmaxhr_u2() * 3600 + KchildlockSettings::wEEKmaxmin_u2() * 60;

   if (KchildlockSettings::sameRestrict_u2()) {
		data->my_actuserstate.lim_du = KchildlockSettings::dAYmaxhr_u2() * 3600 + KchildlockSettings::dAYmaxmin_u2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::dAYfromhr_u2() * 3600 + KchildlockSettings::dAYfrommin_u2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::dAYtohr_u2() * 3600 + KchildlockSettings::dAYtomin_u1() * 60;
   } else {
	if (data->my_actuserstate.date.dayOfWeek() == 1 && KchildlockSettings::mONenabled_u2() )
	{
		data->my_actuserstate.lim_du = KchildlockSettings::mONmaxhr_u2() * 3600 + KchildlockSettings::mONmaxmin_u2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::mONfromhr_u2() * 3600 + KchildlockSettings::mONfrommin_u2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::mONtohr_u2() * 3600 + KchildlockSettings::mONtomin_u2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 2 && KchildlockSettings::tUEenabled_u2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tUEmaxhr_u2() * 3600 + KchildlockSettings::tUEmaxmin_u2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tUEfromhr_u2() * 3600 + KchildlockSettings::tUEfrommin_u2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tUEtohr_u2() * 3600 + KchildlockSettings::tUEtomin_u2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 3 && KchildlockSettings::wEDenabled_u2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::wEDmaxhr_u2() * 3600 + KchildlockSettings::wEDmaxmin_u2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::wEDfromhr_u2() * 3600 + KchildlockSettings::wEDfrommin_u2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::wEDtohr_u2() * 3600 + KchildlockSettings::wEDtomin_u2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 4 && KchildlockSettings::tHUenabled_u2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tHUmaxhr_u2() * 3600 + KchildlockSettings::tHUmaxmin_u2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tHUfromhr_u2() * 3600 + KchildlockSettings::tHUfrommin_u2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tHUtohr_u2() * 3600 + KchildlockSettings::tHUtomin_u2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 5 && KchildlockSettings::fRIenabled_u2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::fRImaxhr_u2() * 3600 + KchildlockSettings::fRImaxmin_u2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::fRIfromhr_u2() * 3600 + KchildlockSettings::fRIfrommin_u2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::fRItohr_u2() * 3600 + KchildlockSettings::fRItomin_u2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 6 && KchildlockSettings::sATenabled_u2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sATmaxhr_u2() * 3600 + KchildlockSettings::sATmaxmin_u2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sATfromhr_u2() * 3600 + KchildlockSettings::sATfrommin_u2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sATtohr_u2() * 3600 + KchildlockSettings::sATtomin_u2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 7 && KchildlockSettings::sUNenabled_u2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sUNmaxhr_u2() * 3600 + KchildlockSettings::sUNmaxmin_u2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sUNfromhr_u2() * 3600 + KchildlockSettings::sUNfrommin_u2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sUNtohr_u2() * 3600 + KchildlockSettings::sUNtomin_u2() * 60;
	}
	else
	{
		data->my_actuserstate.lim_du = 24 * 3600 + KCHILDLOCK_WARNTIME3;
		data->my_actuserstate.lim_f = 0;
		data->my_actuserstate.lim_t = 24 * 3600 + KCHILDLOCK_WARNTIME3;
	}
	return(TRUE);
   }
   return(TRUE);
}



// get the limitations for usr3 if its the active user
// ==================================================
bool KchildlockDaemon::get_user_limits_u3()
{

   if ((data->my_actuserstate.user!= KchildlockSettings::usernamestring_u3()) || 	!(KchildlockSettings::enabled_u3()))
	return(FALSE);

   data->my_actuserstate.date = QDate::currentDate();
   data->my_actuserstate.lim_wu = KchildlockSettings::wEEKmaxhr_u3() * 3600 + KchildlockSettings::wEEKmaxmin_u3() * 60;

   if (KchildlockSettings::sameRestrict_u3()) {
		data->my_actuserstate.lim_du = KchildlockSettings::dAYmaxhr_u3() * 3600 + KchildlockSettings::dAYmaxmin_u3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::dAYfromhr_u3() * 3600 + KchildlockSettings::dAYfrommin_u3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::dAYtohr_u3() * 3600 + KchildlockSettings::dAYtomin_u3() * 60;
   } else {
	if (data->my_actuserstate.date.dayOfWeek() == 1 && KchildlockSettings::mONenabled_u3() )
	{
		data->my_actuserstate.lim_du = KchildlockSettings::mONmaxhr_u3() * 3600 + KchildlockSettings::mONmaxmin_u3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::mONfromhr_u3() * 3600 + KchildlockSettings::mONfrommin_u3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::mONtohr_u3() * 3600 + KchildlockSettings::mONtomin_u3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 2 && KchildlockSettings::tUEenabled_u3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tUEmaxhr_u3() * 3600 + KchildlockSettings::tUEmaxmin_u3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tUEfromhr_u3() * 3600 + KchildlockSettings::tUEfrommin_u3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tUEtohr_u3() * 3600 + KchildlockSettings::tUEtomin_u3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 3 && KchildlockSettings::wEDenabled_u3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::wEDmaxhr_u3() * 3600 + KchildlockSettings::wEDmaxmin_u3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::wEDfromhr_u3() * 3600 + KchildlockSettings::wEDfrommin_u3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::wEDtohr_u3() * 3600 + KchildlockSettings::wEDtomin_u3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 4 && KchildlockSettings::tHUenabled_u3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tHUmaxhr_u3() * 3600 + KchildlockSettings::tHUmaxmin_u3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tHUfromhr_u3() * 3600 + KchildlockSettings::tHUfrommin_u3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tHUtohr_u3() * 3600 + KchildlockSettings::tHUtomin_u3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 5 && KchildlockSettings::fRIenabled_u3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::fRImaxhr_u3() * 3600 + KchildlockSettings::fRImaxmin_u3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::fRIfromhr_u3() * 3600 + KchildlockSettings::fRIfrommin_u3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::fRItohr_u3() * 3600 + KchildlockSettings::fRItomin_u3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 6 && KchildlockSettings::sATenabled_u3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sATmaxhr_u3() * 3600 + KchildlockSettings::sATmaxmin_u3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sATfromhr_u3() * 3600 + KchildlockSettings::sATfrommin_u3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sATtohr_u3() * 3600 + KchildlockSettings::sATtomin_u3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 7 && KchildlockSettings::sUNenabled_u3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sUNmaxhr_u3() * 3600 + KchildlockSettings::sUNmaxmin_u3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sUNfromhr_u3() * 3600 + KchildlockSettings::sUNfrommin_u3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sUNtohr_u3() * 3600 + KchildlockSettings::sUNtomin_u3() * 60;
	}
	else
	{
		data->my_actuserstate.lim_du = 24 * 3600 + KCHILDLOCK_WARNTIME3;
		data->my_actuserstate.lim_f = 0;
		data->my_actuserstate.lim_t = 24 * 3600 + KCHILDLOCK_WARNTIME3;
	}
	return(TRUE);
   }
   return(TRUE);
}






// get the limitations for usr4 if its the active user
// ==================================================
bool KchildlockDaemon::get_user_limits_u4()
{

   if ((data->my_actuserstate.user != KchildlockSettings::usernamestring_u4()) || !(KchildlockSettings::enabled_u4()))
	return(FALSE);

   data->my_actuserstate.date = QDate::currentDate();
   data->my_actuserstate.lim_wu = KchildlockSettings::wEEKmaxhr_u4() * 3600 + KchildlockSettings::wEEKmaxmin_u4() * 60;

   if (KchildlockSettings::sameRestrict_u4()) {
		data->my_actuserstate.lim_du = KchildlockSettings::dAYmaxhr_u4() * 3600 + KchildlockSettings::dAYmaxmin_u4() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::dAYfromhr_u4() * 3600 + KchildlockSettings::dAYfrommin_u4() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::dAYtohr_u4() * 3600 + KchildlockSettings::dAYtomin_u4() * 60;
   } else {
	if (data->my_actuserstate.date.dayOfWeek() == 1 && KchildlockSettings::mONenabled_u4() )
	{
		data->my_actuserstate.lim_du = KchildlockSettings::mONmaxhr_u4() * 3600 + KchildlockSettings::mONmaxmin_u4() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::mONfromhr_u4() * 3600 + KchildlockSettings::mONfrommin_u4() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::mONtohr_u4() * 3600 + KchildlockSettings::mONtomin_u4() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 2 && KchildlockSettings::tUEenabled_u4())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tUEmaxhr_u4() * 3600 + KchildlockSettings::tUEmaxmin_u4() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tUEfromhr_u4() * 3600 + KchildlockSettings::tUEfrommin_u4() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tUEtohr_u4() * 3600 + KchildlockSettings::tUEtomin_u4() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 3 && KchildlockSettings::wEDenabled_u4())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::wEDmaxhr_u4() * 3600 + KchildlockSettings::wEDmaxmin_u4() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::wEDfromhr_u4() * 3600 + KchildlockSettings::wEDfrommin_u4() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::wEDtohr_u4() * 3600 + KchildlockSettings::wEDtomin_u4() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 4 && KchildlockSettings::tHUenabled_u4())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tHUmaxhr_u4() * 3600 + KchildlockSettings::tHUmaxmin_u4() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tHUfromhr_u4() * 3600 + KchildlockSettings::tHUfrommin_u4() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tHUtohr_u4() * 3600 + KchildlockSettings::tHUtomin_u4() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 5 && KchildlockSettings::fRIenabled_u4())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::fRImaxhr_u4() * 3600 + KchildlockSettings::fRImaxmin_u4() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::fRIfromhr_u4() * 3600 + KchildlockSettings::fRIfrommin_u4() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::fRItohr_u4() * 3600 + KchildlockSettings::fRItomin_u4() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 6 && KchildlockSettings::sATenabled_u4())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sATmaxhr_u4() * 3600 + KchildlockSettings::sATmaxmin_u4() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sATfromhr_u4() * 3600 + KchildlockSettings::sATfrommin_u4() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sATtohr_u4() * 3600 + KchildlockSettings::sATtomin_u4() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 7 && KchildlockSettings::sUNenabled_u4())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sUNmaxhr_u4() * 3600 + KchildlockSettings::sUNmaxmin_u4() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sUNfromhr_u4() * 3600 + KchildlockSettings::sUNfrommin_u4() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sUNtohr_u4() * 3600 + KchildlockSettings::sUNtomin_u4() * 60;
	}
	else
	{
		data->my_actuserstate.lim_du = 24 * 3600 + KCHILDLOCK_WARNTIME3;
		data->my_actuserstate.lim_f = 0;
		data->my_actuserstate.lim_t = 24 * 3600 + KCHILDLOCK_WARNTIME3;
	}
	return(TRUE);
   }
   return(TRUE);
}





// get the limitations for usr5 if its the active user
// ==================================================
bool KchildlockDaemon::get_user_limits_u5()
{
   if ((data->my_actuserstate.user != KchildlockSettings::usernamestring_u5()) || !(KchildlockSettings::enabled_u5()))
	return(FALSE);

   data->my_actuserstate.date = QDate::currentDate();
   data->my_actuserstate.lim_wu = KchildlockSettings::wEEKmaxhr_u5() * 3600 + KchildlockSettings::wEEKmaxmin_u5() * 60;

   if (KchildlockSettings::sameRestrict_u5()) {
		data->my_actuserstate.lim_du = KchildlockSettings::dAYmaxhr_u5() * 3600 + KchildlockSettings::dAYmaxmin_u5() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::dAYfromhr_u5() * 3600 + KchildlockSettings::dAYfrommin_u5() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::dAYtohr_u5() * 3600 + KchildlockSettings::dAYtomin_u5() * 60;
   } else {
	if (data->my_actuserstate.date.dayOfWeek() == 1 && KchildlockSettings::mONenabled_u5() )
	{
		data->my_actuserstate.lim_du = KchildlockSettings::mONmaxhr_u5() * 3600 + KchildlockSettings::mONmaxmin_u5() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::mONfromhr_u5() * 3600 + KchildlockSettings::mONfrommin_u5() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::mONtohr_u5() * 3600 + KchildlockSettings::mONtomin_u5() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 2 && KchildlockSettings::tUEenabled_u5())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tUEmaxhr_u5() * 3600 + KchildlockSettings::tUEmaxmin_u5() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tUEfromhr_u5() * 3600 + KchildlockSettings::tUEfrommin_u5() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tUEtohr_u5() * 3600 + KchildlockSettings::tUEtomin_u5() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 3 && KchildlockSettings::wEDenabled_u5())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::wEDmaxhr_u5() * 3600 + KchildlockSettings::wEDmaxmin_u5() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::wEDfromhr_u5() * 3600 + KchildlockSettings::wEDfrommin_u5() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::wEDtohr_u5() * 3600 + KchildlockSettings::wEDtomin_u5() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 4 && KchildlockSettings::tHUenabled_u5())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tHUmaxhr_u5() * 3600 + KchildlockSettings::tHUmaxmin_u5() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tHUfromhr_u5() * 3600 + KchildlockSettings::tHUfrommin_u5() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tHUtohr_u5() * 3600 + KchildlockSettings::tHUtomin_u5() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 5 && KchildlockSettings::fRIenabled_u5())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::fRImaxhr_u5() * 3600 + KchildlockSettings::fRImaxmin_u5() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::fRIfromhr_u5() * 3600 + KchildlockSettings::fRIfrommin_u5() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::fRItohr_u5() * 3600 + KchildlockSettings::fRItomin_u5() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 6 && KchildlockSettings::sATenabled_u5())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sATmaxhr_u5() * 3600 + KchildlockSettings::sATmaxmin_u5() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sATfromhr_u5() * 3600 + KchildlockSettings::sATfrommin_u5() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sATtohr_u5() * 3600 + KchildlockSettings::sATtomin_u5() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 7 && KchildlockSettings::sUNenabled_u5())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sUNmaxhr_u5() * 3600 + KchildlockSettings::sUNmaxmin_u5() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sUNfromhr_u5() * 3600 + KchildlockSettings::sUNfrommin_u5() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sUNtohr_u5() * 3600 + KchildlockSettings::sUNtomin_u5() * 60;
	}
	else
	{
		data->my_actuserstate.lim_du = 24 * 3600 + KCHILDLOCK_WARNTIME3;
		data->my_actuserstate.lim_f = 0;
		data->my_actuserstate.lim_t = 24 * 3600 + KCHILDLOCK_WARNTIME3;
	}
	return(TRUE);
   }
   return(TRUE);
}







// get the limitations for grp1 if its the active user
// ==================================================
bool KchildlockDaemon::get_user_limits_g1()
{
   QStringList myuserlist;
   const char *mygroupn;
   KUserGroup mygroup;
   long mygid;
   bool ismember;

   mygroupn = (KchildlockSettings::groupnamestring_g1()).toAscii().constData();
   mygroup = KUserGroup(mygroupn);
   myuserlist = mygroup.userNames();
   mygid = mygroup.gid();
   ismember = FALSE;

   for ( QStringList::Iterator it = myuserlist.begin(); it != myuserlist.end(); ++it ) {
	if ((*it) != data->my_actuserstate.user)
		ismember = TRUE;
   }
   if (!ismember || !(KchildlockSettings::enabled_g1())) 
	return(FALSE);


   data->my_actuserstate.date = QDate::currentDate();
   data->my_actuserstate.lim_wu = KchildlockSettings::wEEKmaxhr_g1() * 3600 + KchildlockSettings::wEEKmaxmin_g1() * 60;

   if (KchildlockSettings::sameRestrict_g1()) {
	data->my_actuserstate.lim_du = KchildlockSettings::dAYmaxhr_g1() * 3600 + KchildlockSettings::dAYmaxmin_g1() * 60;
	data->my_actuserstate.lim_f = KchildlockSettings::dAYfromhr_g1() * 3600 + KchildlockSettings::dAYfrommin_g1() * 60;
	data->my_actuserstate.lim_t = KchildlockSettings::dAYtohr_g1() * 3600 + KchildlockSettings::dAYtomin_g1() * 60;
   } else {
	if (data->my_actuserstate.date.dayOfWeek() == 1 && KchildlockSettings::mONenabled_g1() )
	{
		data->my_actuserstate.lim_du = KchildlockSettings::mONmaxhr_g1() * 3600 + KchildlockSettings::mONmaxmin_g1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::mONfromhr_g1() * 3600 + KchildlockSettings::mONfrommin_g1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::mONtohr_g1() * 3600 + KchildlockSettings::mONtomin_g1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 2 && KchildlockSettings::tUEenabled_g1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tUEmaxhr_g1() * 3600 + KchildlockSettings::tUEmaxmin_g1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tUEfromhr_g1() * 3600 + KchildlockSettings::tUEfrommin_g1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tUEtohr_g1() * 3600 + KchildlockSettings::tUEtomin_g1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 3 && KchildlockSettings::wEDenabled_g1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::wEDmaxhr_g1() * 3600 + KchildlockSettings::wEDmaxmin_g1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::wEDfromhr_g1() * 3600 + KchildlockSettings::wEDfrommin_g1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::wEDtohr_g1() * 3600 + KchildlockSettings::wEDtomin_g1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 4 && KchildlockSettings::tHUenabled_g1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tHUmaxhr_g1() * 3600 + KchildlockSettings::tHUmaxmin_g1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tHUfromhr_g1() * 3600 + KchildlockSettings::tHUfrommin_g1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tHUtohr_g1() * 3600 + KchildlockSettings::tHUtomin_g1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 5 && KchildlockSettings::fRIenabled_g1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::fRImaxhr_g1() * 3600 + KchildlockSettings::fRImaxmin_g1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::fRIfromhr_g1() * 3600 + KchildlockSettings::fRIfrommin_g1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::fRItohr_g1() * 3600 + KchildlockSettings::fRItomin_g1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 6 && KchildlockSettings::sATenabled_g1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sATmaxhr_g1() * 3600 + KchildlockSettings::sATmaxmin_g1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sATfromhr_g1() * 3600 + KchildlockSettings::sATfrommin_g1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sATtohr_g1() * 3600 + KchildlockSettings::sATtomin_g1() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 7 && KchildlockSettings::sUNenabled_g1())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sUNmaxhr_g1() * 3600 + KchildlockSettings::sUNmaxmin_g1() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sUNfromhr_g1() * 3600 + KchildlockSettings::sUNfrommin_g1() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sUNtohr_g1() * 3600 + KchildlockSettings::sUNtomin_g1() * 60;
	}
	else
	{
		data->my_actuserstate.lim_du = 24 * 3600 + KCHILDLOCK_WARNTIME3;
		data->my_actuserstate.lim_f = 0;
		data->my_actuserstate.lim_t = 24 * 3600 + KCHILDLOCK_WARNTIME3;
	}
	return(TRUE);
   }
   return(TRUE);
}




// get the limitations for grp2 if its the active user
// ==================================================
bool KchildlockDaemon::get_user_limits_g2()
{
   QStringList myuserlist;
   const char *mygroupn;
   KUserGroup mygroup;
   long mygid;
   bool ismember;

   mygroupn = (KchildlockSettings::groupnamestring_g2()).toAscii().constData();
   mygroup = KUserGroup(mygroupn);
   myuserlist = mygroup.userNames();
   mygid = mygroup.gid();
   ismember = FALSE;

   for ( QStringList::Iterator it = myuserlist.begin(); it != myuserlist.end(); ++it ) {
   	if ((*it) != data->my_actuserstate.user)
		ismember = TRUE;
   }
   if (!ismember || !(KchildlockSettings::enabled_g2())) 
	return(FALSE);

   data->my_actuserstate.date = QDate::currentDate();
   data->my_actuserstate.lim_wu = KchildlockSettings::wEEKmaxhr_g2() * 3600 + KchildlockSettings::wEEKmaxmin_g2() * 60;

   if (KchildlockSettings::sameRestrict_g2) {
		data->my_actuserstate.lim_du = KchildlockSettings::dAYmaxhr_g2() * 3600 + KchildlockSettings::dAYmaxmin_g2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::dAYfromhr_g2() * 3600 + KchildlockSettings::dAYfrommin_g2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::dAYtohr_g2() * 3600 + KchildlockSettings::dAYtomin_g2() * 60;
   } else {
	if (data->my_actuserstate.date.dayOfWeek() == 1 && KchildlockSettings::mONenabled_g2() )
	{
		data->my_actuserstate.lim_du = KchildlockSettings::mONmaxhr_g2() * 3600 + KchildlockSettings::mONmaxmin_g2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::mONfromhr_g2() * 3600 + KchildlockSettings::mONfrommin_g2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::mONtohr_g2() * 3600 + KchildlockSettings::mONtomin_g2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 2 && KchildlockSettings::tUEenabled_g2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tUEmaxhr_g2() * 3600 + KchildlockSettings::tUEmaxmin_g2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tUEfromhr_g2() * 3600 + KchildlockSettings::tUEfrommin_g2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tUEtohr_g2() * 3600 + KchildlockSettings::tUEtomin_g2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 3 && KchildlockSettings::wEDenabled_g2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::wEDmaxhr_g2() * 3600 + KchildlockSettings::wEDmaxmin_g2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::wEDfromhr_g2() * 3600 + KchildlockSettings::wEDfrommin_g2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::wEDtohr_g2() * 3600 + KchildlockSettings::wEDtomin_g2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 4 && KchildlockSettings::tHUenabled_g2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tHUmaxhr_g2() * 3600 + KchildlockSettings::tHUmaxmin_g2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tHUfromhr_g2() * 3600 + KchildlockSettings::tHUfrommin_g2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tHUtohr_g2() * 3600 + KchildlockSettings::tHUtomin_g2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 5 && KchildlockSettings::fRIenabled_g2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::fRImaxhr_g2() * 3600 + KchildlockSettings::fRImaxmin_g2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::fRIfromhr_g2() * 3600 + KchildlockSettings::fRIfrommin_g2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::fRItohr_g2() * 3600 + KchildlockSettings::fRItomin_g2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 6 && KchildlockSettings::sATenabled_g2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sATmaxhr_g2() * 3600 + KchildlockSettings::sATmaxmin_g2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sATfromhr_g2() * 3600 + KchildlockSettings::sATfrommin_g2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sATtohr_g2() * 3600 + KchildlockSettings::sATtomin_g2() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 7 && KchildlockSettings::sUNenabled_g2())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sUNmaxhr_g2() * 3600 + KchildlockSettings::sUNmaxmin_g2() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sUNfromhr_g2() * 3600 + KchildlockSettings::sUNfrommin_g2() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sUNtohr_g2() * 3600 + KchildlockSettings::sUNtomin_g2() * 60;
	}
	else
	{
		data->my_actuserstate.lim_du = 24 * 3600 + KCHILDLOCK_WARNTIME3;
		data->my_actuserstate.lim_f = 0;
		data->my_actuserstate.lim_t = 24 * 3600 + KCHILDLOCK_WARNTIME3;
	}
	return(TRUE);
   }
   return(TRUE);
}





// get the limitations for grp3 if its the active user
// ==================================================
bool KchildlockDaemon::get_user_limits_g3()
{
   QStringList myuserlist;
   const char *mygroupn;
   KUserGroup mygroup;
   long mygid;
   bool ismember;

   mygroupn = (KchildlockSettings::groupnamestring_g3()).toAscii().constData();
   mygroup = KUserGroup(mygroupn);
   myuserlist = mygroup.userNames();
   mygid = mygroup.gid();
   ismember = FALSE;

   for ( QStringList::Iterator it = myuserlist.begin(); it != myuserlist.end(); ++it ) {
	if ((*it) != data->my_actuserstate.user)
		ismember = TRUE;
}
   if (!ismember || !(KchildlockSettings::enabled_g3())) 
	return(FALSE);

   data->my_actuserstate.date = QDate::currentDate();
   data->my_actuserstate.lim_wu = KchildlockSettings::wEEKmaxhr_g3() * 3600 + KchildlockSettings::wEEKmaxmin_g3() * 60;

   if (KchildlockSettings::sameRestrict_g3()) {
		data->my_actuserstate.lim_du = KchildlockSettings::dAYmaxhr_g3() * 3600 + KchildlockSettings::dAYmaxmin_g3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::dAYfromhr_g3() * 3600 + KchildlockSettings::dAYfrommin_g3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::dAYtohr_g3() * 3600 + KchildlockSettings::dAYtomin_g3() * 60;
   } else {
	if (data->my_actuserstate.date.dayOfWeek() == 1 && KchildlockSettings::mONenabled_g3() )
	{
		data->my_actuserstate.lim_du = KchildlockSettings::mONmaxhr_g3() * 3600 + KchildlockSettings::mONmaxmin_g3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::mONfromhr_g3() * 3600 + KchildlockSettings::mONfrommin_g3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::mONtohr_g3() * 3600 + KchildlockSettings::mONtomin_g3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 2 && KchildlockSettings::tUEenabled_g3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tUEmaxhr_g3() * 3600 + KchildlockSettings::tUEmaxmin_g3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tUEfromhr_g3() * 3600 + KchildlockSettings::tUEfrommin_g3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tUEtohr_g3() * 3600 + KchildlockSettings::tUEtomin_g3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 3 && KchildlockSettings::wEDenabled_g3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::wEDmaxhr_g3() * 3600 + KchildlockSettings::wEDmaxmin_g3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::wEDfromhr_g3() * 3600 + KchildlockSettings::wEDfrommin_g3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::wEDtohr_g3() * 3600 + KchildlockSettings::wEDtomin_g3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 4 && KchildlockSettings::tHUenabled_g3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::tHUmaxhr_g3() * 3600 + KchildlockSettings::tHUmaxmin_g3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::tHUfromhr_g3() * 3600 + KchildlockSettings::tHUfrommin_g3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::tHUtohr_g3() * 3600 + KchildlockSettings::tHUtomin_g3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 5 && KchildlockSettings::fRIenabled_g3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::fRImaxhr_g3() * 3600 + KchildlockSettings::fRImaxmin_g3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::fRIfromhr_g3() * 3600 + KchildlockSettings::fRIfrommin_g3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::fRItohr_g3() * 3600 + KchildlockSettings::fRItomin_g3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 6 && KchildlockSettings::sATenabled_g3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sATmaxhr_g3() * 3600 + KchildlockSettings::sATmaxmin_g3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sATfromhr_g3() * 3600 + KchildlockSettings::sATfrommin_g3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sATtohr_g3() * 3600 + KchildlockSettings::sATtomin_g3() * 60;
	}
	else if (data->my_actuserstate.date.dayOfWeek() == 7 && KchildlockSettings::sUNenabled_g3())
	{
		data->my_actuserstate.lim_du = KchildlockSettings::sUNmaxhr_g3() * 3600 + KchildlockSettings::sUNmaxmin_g3() * 60;
		data->my_actuserstate.lim_f = KchildlockSettings::sUNfromhr_g3() * 3600 + KchildlockSettings::sUNfrommin_g3() * 60;
		data->my_actuserstate.lim_t = KchildlockSettings::sUNtohr_g3() * 3600 + KchildlockSettings::sUNtomin_g3() * 60;
	}
	else
	{
		data->my_actuserstate.lim_du = 24 * 3600 + KCHILDLOCK_WARNTIME3;
		data->my_actuserstate.lim_f = 0;
		data->my_actuserstate.lim_t = 24 * 3600 + KCHILDLOCK_WARNTIME3;
	}
	return(TRUE);
   }
   return(TRUE);
}
