/***************************************************************************
 *   Copyright (C) 2009 by Rene Landert <rene.landert@bluewin.ch>          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************
 *                                                                         *
 *   Part of the code in this file was taken from KDE4Powersave and/or     *
 *   Lithium, where noticed.                                               *
 *                                                                         *
 **************************************************************************/

#include "KchildlockDaemon.h"

#include <klocalizedstring.h>
#include <kdebug.h>
#include <kuser.h>





// do the monitoring of usage for a given user
// ===========================================
void KchildlockDaemon::monitor_user()
{
	bool restricted;

        if (data->ckAvailable == false) return;                     // no console kit
	if (data->my_actuserstate.user == "") return;			// no session active
	data->my_actuserstate.date = QDate::currentDate();
	if (my_ctfile->weekofyear_ct != data->my_actuserstate.date.weekNumber())
	{
		// its a new week, reset all daily/weekly working set values to zero
		my_ctfile->set_default_values(data->my_actuserstate.user);
	}
	if (my_ctfile->dayofweek_ct != data->my_actuserstate.date.dayOfWeek())
	{
		// its a new day, reset all daily working set values to zero
                my_ctfile->reset_daily_values();
		data->my_actuserstate.warn_usr_state = KCHILDLOCK_NOWARNSTATE;
		data->my_actuserstate.warn_app_state = KCHILDLOCK_NOWARNSTATE;

	}
	
	if (data->debugflag) {
		fprintf (data->debugf,"function=monitor_user user=%s at %i.%i.%i %i:%i:%i\n", data->my_actuserstate.user.toAscii().constData(), data->my_actuserstate.date.day(), data->my_actuserstate.date.month(), data->my_actuserstate.date.year(), data->my_actuserstate.time.hour(), data->my_actuserstate.time.minute(), data->my_actuserstate.time.second());
                fflush(data->debugf);
	        }

// check for pc usage limits
	restricted = get_user_limits_u1();
	if (restricted)
		check_user_against_limits();
	restricted = get_user_limits_u2();
	if (restricted)
		check_user_against_limits();
	restricted = get_user_limits_u3();
	if (restricted)
		check_user_against_limits();
	restricted = get_user_limits_u4();
	if (restricted)
		check_user_against_limits();
	restricted = get_user_limits_u5();
	if (restricted)
		check_user_against_limits();
	
	restricted = get_user_limits_g1();
	if (restricted)
		check_user_against_limits();
	restricted = get_user_limits_g2();
	if (restricted)
		check_user_against_limits();
	restricted = get_user_limits_g3();
	if (restricted)
		check_user_against_limits();

// check for application usage limits
	restricted = get_app_limits_u1();
	if (restricted)
		check_user_against_applimits();
	restricted = get_app_limits_u2();
	if (restricted)
		check_user_against_applimits();
	restricted = get_app_limits_u3();
	if (restricted)
		check_user_against_applimits();
	restricted = get_app_limits_u4();
	if (restricted)
		check_user_against_applimits();
	restricted = get_app_limits_u5();
	if (restricted)
		check_user_against_applimits();

}





// get the current active KDE User
// ===============================
void KchildlockDaemon::get_active_user()
{

/* the command line is:

# dbus-send --system --dest=org.freedesktop.ConsoleKit   --type=method_call --print-reply --reply-timeout=2000   /org/freedesktop/ConsoleKit/Seat1   org.freedesktop.ConsoleKit.Seat.GetActiveSession
method return sender=:1.1 -> dest=:1.71 reply_serial=2
Answer:   object path "/org/freedesktop/ConsoleKit/Session1"

dbus-send --system --dest=org.freedesktop.ConsoleKit   --type=method_call --print-reply --reply-timeout=2000   /org/freedesktop/ConsoleKit/Session1   org.freedesktop.ConsoleKit.Session.GetUnixUser
method return sender=:1.1 -> dest=:1.56 reply_serial=2
   int32 1000
*/

   int userid;
   bool okcode;

    QDBusInterface *ckseatiface = new QDBusInterface("org.freedesktop.ConsoleKit", "/org/freedesktop/ConsoleKit/Seat1",
                           "org.freedesktop.ConsoleKit.Seat", QDBusConnection::systemBus());

    QDBusReply<QDBusObjectPath> actsessionPath = ckseatiface->call("GetActiveSession");
    if (data->debugflag) {
	fprintf (data->debugf,"function=get_active_user 1: actsessionPath=%s\n", actsessionPath.value().path().toAscii().constData());
        fflush(data->debugf);
	}

    if (!actsessionPath.isValid() || actsessionPath.value().path().isEmpty()) {
        kDebug() << "The active session is not registered with ConsoleKit";
        data->ckAvailable = false;
	if (data->debugflag) {
		fprintf (data->debugf,"function=get_active_user 2: no active session\n");
                fflush(data->debugf);
	        }
	userid = 0;
        return;
    }
    ckseatiface->~QDBusInterface();

    QDBusInterface *cksessioniface = new QDBusInterface("org.freedesktop.ConsoleKit", actsessionPath.value().path(),
            "org.freedesktop.ConsoleKit.Session", QDBusConnection::systemBus());

//    QDBusReply<int> userid = cksessioniface->call("GetUnixUser");
    QDBusMessage reply = cksessioniface->call("GetUnixUser");
    if (reply.type() == QDBusMessage::ErrorMessage) {
       userid = 0;
       QDBusError err = reply;
       if (data->debugflag) {
		fprintf (data->debugf,"function=get_active_user: Error %s\n%s\n", (err.name()).toAscii().constData(), (err.message()).toAscii().constData());
                fflush(data->debugf);
	        }
    } else if (reply.type() != QDBusMessage::ReplyMessage) {
       if (data->debugflag) {
		fprintf (data->debugf,"function=get_active_user: Error Invalid reply type %d\n", int(reply.type()));
                fflush(data->debugf);
	        }
	userid = 0;
    }       
    foreach (QVariant v, reply.arguments())
    {
       if (v.userType() == QVariant::StringList) {
// do nothing with an unexpected answer
       }
       else if (v.userType() == qMetaTypeId<QDBusArgument>()) {
// do nothing with an unexpected answer
      } else {
           userid = (v.toString()).toInt(&okcode, 10);
      } 
    }

    QDBusReply<QString> dispid = cksessioniface->call("GetX11Display");
    KUser my_kuser = KUser((int)userid);
    data->my_actuserstate.user = my_kuser.loginName();
    data->my_actuserstate.disp = dispid;
    if (data->debugflag) {
	fprintf (data->debugf,"function=get_active_user 4: userid=%i dispid=%s username=%s\n", (int)userid, ((QString)dispid).toAscii().constData(), data->my_actuserstate.user.toAscii().constData());
        fflush(data->debugf);
	}
    cksessioniface->~QDBusInterface();

//    delete ckseatiface;
//    delete cksessioniface;
//    delete &my_kuser;
}

