/***************************************************************************
 *   Copyright (C) 2009 by Rene Landert <rene.landert@bluewin.ch>          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 **************************************************************************/

#include "KchildlockDaemon.h"

#include <klocale.h>
#include <kmessagebox.h>





// force logout of the active session on the PC
// ============================================
void KchildlockDaemon::force_logout_session()
{
/* the command line is:

# dbus-send --system --dest=org.freedesktop.ConsoleKit   --type=method_call --print-reply --reply-timeout=2000   /org/freedesktop/ConsoleKit/Seat1   org.freedesktop.ConsoleKit.Seat.GetActiveSession
method return sender=:1.1 -> dest=:1.71 reply_serial=2
Answer:   object path "/org/freedesktop/ConsoleKit/Session1"

dbus-send --system --dest=org.freedesktop.ConsoleKit   --type=method_call --print-reply --reply-timeout=2000   /org/freedesktop/ConsoleKit/Manager   org.freedesktop.ConsoleKit.Manager.CloseSession
method return sender=:1.1 -> dest=:1.56 reply_serial=2
   int32 1000

dbus-send --session --dest=org.kde.ksmserver  --type=method_call --print-reply --reply-timeout=2000   /KSMServer   org.kde.KSMServerInterface.logout
method return sender=:1.1 -> dest=:1.56 reply_serial=2
   int32 1int32 1 int32 1
*/
    QDBusInterface *ckmgriface = new QDBusInterface("org.kde.ksmserver", "/KSMServer",
                           "org.kde.KSMServerInterface", QDBusConnection::sessionBus());

//    QString sessioncookie = getenv ("XDG_SESSION_COOKIE");

//    QDBusReply<bool> result = ckmgriface->call(QLatin1String("CloseSession"), sessioncookie);
    QDBusReply<QString> reply = ckmgriface->call(QLatin1String("logout"),0,0,2);

/*
The three numbers are explained below (see source):
First parameter: confirm
 Obey the user’s confirmation setting: -1
 Don’t confirm, shutdown without asking: 0
 Always confirm, ask even if the user turned it off: 1
 Second parameter: type
 Select previous action or the default if it’s the first time: -1
 Only log out: 0
 Log out and reboot the machine: 1
 Log out and halt the machine: 2
 Third parameter: mode
 Select previous mode or the default if it’s the first time: -1
 Schedule a shutdown (halt or reboot) for the time all active sessions have
 exited: 0
 Shut down, if no sessions are active. Otherwise do nothing: 1
 Force shutdown. Kill any possibly active sessions: 2
 Pop up a dialog asking the user what to do if sessions are still active: 3
*/

     if (data->debugflag) {
		fprintf (data->debugf,"function=force_logout_session user=%s disp=%s replyvalid=%i reply=%s at %i.%i. %i:%i:%i\n", data->my_actuserstate.user.toAscii().constData(), data->my_actuserstate.disp.toAscii().constData(), reply.isValid(), reply.value().toAscii().constData(), data->my_actuserstate.date.day(), data->my_actuserstate.date.month(), data->my_actuserstate.time.hour(), data->my_actuserstate.time.minute(), data->my_actuserstate.time.second());
    }

}





// display a warning message and eventually logout the user
// ========================================================
void KchildlockDaemon::warning_or_logout_session (int warn_level)
{
	
		
// set the environment and display the notification to the user

	if (data->debugflag) 
		fprintf (data->debugf,"function=warning_or_logout_session begin user=%s disp=%s warnlevel=%i at %i.%i. %i:%i:%i\n", data->my_actuserstate.user.toAscii().constData(), data->my_actuserstate.disp.toAscii().constData(), warn_level, data->my_actuserstate.date.day(), data->my_actuserstate.date.month(), data->my_actuserstate.time.hour(), data->my_actuserstate.time.minute(), data->my_actuserstate.time.second());


	if (warn_level == KCHILDLOCK_WARNSTATE3)
	{
//           KNotification::event("warning3", I18N_NOOP("The Usage time for you is restricted. You will be automatically logged out in 15 minutes."), KIcon("pattern-xfce").pixmap(20, 20), 0, KNotification::CloseOnTimeout, data->applicationData);
           KMessageBox::queuedMessageBox (0, KMessageBox::Error, I18N_NOOP("The Usage time for you is restricted. You will be automatically logged out in 15 minutes."), I18N_NOOP("Children Lock"));
	}
	else if (warn_level == KCHILDLOCK_WARNSTATE2)
	{
//           KNotification::event("warning2", I18N_NOOP("The Usage time for you is restricted. You will be automatically logged out in 10 minutes."), KIcon("pattern-xfce").pixmap(20, 20), 0, KNotification::CloseOnTimeout, data->applicationData);
           KMessageBox::queuedMessageBox (0, KMessageBox::Error, I18N_NOOP("The Usage time for you is restricted. You will be automatically logged out in 10 minutes."), I18N_NOOP("Children Lock"));
	}
	else if (warn_level == KCHILDLOCK_WARNSTATE1)
	{
//           KNotification::event("warning1", I18N_NOOP("The Usage time for you is restricted. You will be automatically logged out in 5 minutes."), KIcon("pattern-xfce").pixmap(20, 20), 0, KNotification::CloseOnTimeout, data->applicationData);
           KMessageBox::queuedMessageBox (0, KMessageBox::Error, I18N_NOOP("The Usage time for you is restricted. You will be automatically logged out in 5 minutes."), I18N_NOOP("Children Lock"));
	}
	else if (warn_level == KCHILDLOCK_WARNSTATE0)
	{
//           KNotification::event("warning0", I18N_NOOP("The Usage time for you is restricted. You will be automatically logged out in 30 seconds."), KIcon("pattern-xfce").pixmap(20, 20), 0, KNotification::Persistent, data->applicationData);
//           KMessageBox::error (0, I18N_NOOP("The Usage time for you is restricted. You will be automatically logged out in 1 minute."), I18N_NOOP("Children Lock"), KMessageBox::Notify);
           KMessageBox::queuedMessageBox (0, KMessageBox::Error, I18N_NOOP("The Usage time for you is restricted. You will be automatically logged out in 1 minute."), I18N_NOOP("Children Lock"));
	} else
	{
		// wrong calling parameter
	}


// logout the user after 20 seconds
	if (warn_level == KCHILDLOCK_WARNSTATE00)
	{
//		sleep (30);
		if (data->debugflag) 
			fprintf (data->debugf,"function=warning_or_logout_session end at %i.%i. %i:%i:%i\n", data->my_actuserstate.date.day(), data->my_actuserstate.date.month(), data->my_actuserstate.time.hour(), data->my_actuserstate.time.minute(), data->my_actuserstate.time.second());

		force_logout_session();
	
	}
	
}

