/***************************************************************************
 *   Copyright (C) 2009 by Rene Landert <rene.landert@bluewin.ch>          *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef _KCHILDLOCKCONF_H_
#define _KCHILDLOCKCONF_H_

#include <kconfigdialog.h>
#include <kconfigskeleton.h>

#include "ui_userPage.h"
#include "ui_groupPage.h"
#include "ui_generalPage.h"

#define USERIDLOWLIMIT 200
#define GROUPIDLOWLIMIT 100

class KPrinter;
class KURL;

/**
 * This class serves as the main window for KChildlock.  It handles the
 * menus, toolbars, and status bars.
 *
 * @short Main window class
 * @author Rene Landert <rene.landert@bluewin.ch>
 * @version 0.1
 */



/** KchildlockConf is the base class of the project */
class KchildlockConf : public KConfigDialog
{
  Q_OBJECT
  public:
    /** construtor */
    KchildlockConf(QWidget* parent = 0, const char * name = 0, KConfigSkeleton *config = 0); 
    /** destructor */
    ~KchildlockConf();
    void load();
    void save();
    void defaults();
    void set_defaults_for_user(Ui_userPage *user);
    void set_defaults_for_group(Ui_groupPage *group);
    void disableSameSettings_u1();
    void disableDifferentSettings_u1();
    void disableSameSettings_u2();
    void disableDifferentSettings_u2();
    void disableSameSettings_u3();
    void disableDifferentSettings_u3();
    void disableSameSettings_u4();
    void disableDifferentSettings_u4();
    void disableSameSettings_u5();
    void disableDifferentSettings_u5();
    void disableSameSettings_g1();
    void disableDifferentSettings_g1();
    void disableSameSettings_g2();
    void disableDifferentSettings_g2();
    void disableSameSettings_g3();
    void disableDifferentSettings_g3();

    void fillValuesInGui_gen();
    void fillValuesInGui_u1(Ui_userPage *usergroup);
    void fillValuesInGui_u2(Ui_userPage *usergroup);
    void fillValuesInGui_u3(Ui_userPage *usergroup);
    void fillValuesInGui_u4(Ui_userPage *usergroup);
    void fillValuesInGui_u5(Ui_userPage *usergroup);
    void fillValuesInGui_g1(Ui_groupPage *usergroup);
    void fillValuesInGui_g2(Ui_groupPage *usergroup);
    void fillValuesInGui_g3(Ui_groupPage *usergroup);
    
    
    void connect_general();
    void connect_u1();
    void connect_u2();
    void connect_u3();
    void connect_u4();
    void connect_u5();
    void connect_g1();
    void connect_g2();
    void connect_g3();

  private:
    bool reloaded;
    bool readOnly;
    bool modified;
    QStringList getlistofusers();
    QStringList getlistofgroups();
    Ui_generalPage *general;
    Ui_userPage *user1;
    Ui_userPage *user2;
    Ui_userPage *user3;
    Ui_userPage *user4;
    Ui_userPage *user5;
    Ui_groupPage *group1;
    Ui_groupPage *group2;
    Ui_groupPage *group3;
  public slots:
    void updateConfiguration();

  signals:
    void kchildlockModified(bool);
    void changed(bool ch);

  private slots:

//  Signals for General Settings
    void emitChanged_enable_restrictions(int);
    void emitChanged_scaninterval(int);

//  Signals for User1
    void emitChanged_enabled_u1(int);
    void emitChanged_username_u1(QString);
    void emitChanged_sameRestrict_u1(bool);
    void emitChanged_diffRestrict_u1(bool);
    void emitChanged_value_u1(int);
    void emitChanged_appname_u1(QString);

//  Signals for User2
    void emitChanged_enabled_u2(int);
    void emitChanged_username_u2(QString);
    void emitChanged_sameRestrict_u2(bool);
    void emitChanged_diffRestrict_u2(bool);
    void emitChanged_value_u2(int);
    void emitChanged_appname_u2(QString);

//  Signals for User3
    void emitChanged_enabled_u3(int);
    void emitChanged_username_u3(QString);
    void emitChanged_sameRestrict_u3(bool);
    void emitChanged_diffRestrict_u3(bool);
    void emitChanged_value_u3(int);
    void emitChanged_appname_u3(QString);

//  Signals for User4
    void emitChanged_enabled_u4(int);
    void emitChanged_username_u4(QString);
    void emitChanged_sameRestrict_u4(bool);
    void emitChanged_diffRestrict_u4(bool);
    void emitChanged_value_u4(int);
    void emitChanged_appname_u4(QString);

//  Signals for User5
    void emitChanged_enabled_u5(int);
    void emitChanged_username_u5(QString);
    void emitChanged_sameRestrict_u5(bool);
    void emitChanged_diffRestrict_u5(bool);
    void emitChanged_value_u5(int);
    void emitChanged_appname_u5(QString);

//  Signals for Group1
    void emitChanged_enabled_g1(int);
    void emitChanged_groupname_g1(QString);
    void emitChanged_sameRestrict_g1(bool);
    void emitChanged_diffRestrict_g1(bool);
    void emitChanged_value_g1(int);

//  Signals for Group2
    void emitChanged_enabled_g2(int);
    void emitChanged_groupname_g2(QString);
    void emitChanged_sameRestrict_g2(bool);
    void emitChanged_diffRestrict_g2(bool);
    void emitChanged_value_g2(int);

//  Signals for Group3
    void emitChanged_enabled_g3(int);
    void emitChanged_groupname_g3(QString);
    void emitChanged_sameRestrict_g3(bool);
    void emitChanged_diffRestrict_g3(bool);
    void emitChanged_value_g3(int);

  signals:
    void settingsChanged();
};


#endif // _KCHILDLOCK_H_

