 /***************************************************************************
 *   Copyright (C) 2009 by Rene Landert <rene.landert@bluewin.ch>          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#include "KchildlockKCM.h"
#include "KchildlockConf.h"
#include "kchildlock.h"

#include <KPluginFactory>
#include <KAboutData>
#include <QVBoxLayout>


K_PLUGIN_FACTORY(KchildlockFactory,
                 registerPlugin<KchildlockKCM>();
                )
K_EXPORT_PLUGIN(KchildlockFactory("kcm_kchildlock"))

KchildlockKCM::KchildlockKCM(QWidget *parent, const QVariantList &args) :
        KCModule(KchildlockFactory::componentData(), parent, args)
//        m_dbus(QDBusConnection::sessionBus()) 

{
    KGlobal::locale()->insertCatalog("kchildlock");

    KAboutData *about =
        new KAboutData("kcmkchildlock", "kchildlock", ki18n("Kchildlock Configuration"),
                       KCHILDLOCK_VERSION, ki18n("A configurator for Kchildlock"),
                       KAboutData::License_GPL, ki18n("(c), 2010 Rene Landert"),
                       ki18n("From this module, you can configure the Kchildlock Daemon, "
                             "which restricts the usage time of the computer and of applications per day and "
                             "per week for selected users. "));

    about->addAuthor(ki18n("Rene Landert"), ki18n("Main Developer") , "rene.landert@bluewin.ch", "http://www.sourceforge.net/kchildlock");

    setAboutData(about);
    setButtons(KCModule::Apply|KCModule::Help|KCModule::Default);

    setQuickHelp(i18n("<h1>Kchildlock configuration</h1> <p>This module lets you configure "
                      "Kchildlock. Kchildlock is a daemon (so it runs in background) that is started "
                      "upon KDE startup.</p> <p>Kchildlock has 3 levels of configuration: a general one, "
                      "with common settings, 5 possible users for whom you can configure the restrictions, "
                      "and 3 groups for whom you can configure the restrictions."
                      "Each tab for the user or group lets you edit the restriction details. "
                      "You do not have to restart Kchildlock, just click on the button "
                      "'Apply', and you are done.</p>"));

    if (getuid() != 0){
        KMessageBox::information(0,i18n("Only root can call this program!"));
        return;
    }

    my_kcconf = new KchildlockConf(parent,"settings",KchildlockSettings::self());
    
    connect(my_kcconf, SIGNAL(changed(bool)), this, SIGNAL(changed(bool)));
    connect (my_kcconf, SIGNAL(settingsChanged(const QString&)), this, SLOT(load()));


    QVBoxLayout *m_layout = new QVBoxLayout(this);
    m_layout->setSpacing(KDialog::spacingHint());
    m_layout->setMargin(0);

    m_layout->addWidget(my_kcconf);

}


KchildlockKCM::~KchildlockKCM()
{
}


void KchildlockKCM::load()
{
   if (getuid() != 0) return;
   kDebug() << "MessageKCM load";
   my_kcconf->load();
}

void KchildlockKCM::save()
{
   if (getuid() != 0) return;
   kDebug() << "Message KCM save";
   my_kcconf->save();
}

void KchildlockKCM::defaults()
{
   if (getuid() != 0) return;
   kDebug() << "Message KCM defaults";
   my_kcconf->defaults();
}

bool KchildlockKCM::useRootOnlyMsg() const
{
  return true;
}

QString KchildlockKCM::rootOnlyMsg() const
{
  return "Changing the kchildlock configuration requires root access";
}


QString KchildlockKCM::quickHelp() const
{
  return i18n("<h1>Kchildlock configuration</h1><p>This module allows you to configure your childrens restriction settings.</p>");
}



#include "KchildlockKCM.moc"
